@@ -36,8 +36,7 @@ public:
     void setEditorData(QWidget *editor, const QModelIndex &index) const;
     void setModelData(QWidget *editor, QAbstractItemModel *model,
                       const QModelIndex &index) const;
-
-private slots:
+private Q_SLOTS:
     void emitCommitData();
 };
 
